# 马蜂窝CEO陈罡：AI时代的旅游平台转型

从内容到服务，AI如何重塑旅游行业

您的浏览器不支持音频播放

*若商用，需要声明由扣子空间生成

## 播客字幕

主持人: 哈喽大家好欢迎收听我们这一期的播客，然后今天咱们来聊一聊这个马蜂窝的 CEO 陈罡。在 AI 时代的一些新的动作啊，包括他们怎么用 AI 来驱动，从内容到服务的转型。包括他们发布的这个所谓的精调垂直模型，以及他们跟地方政府的一些合作。

嘉宾: 听起来非常有意思，那我们就直接来看看马蜂窝是如何利用这些创新来打造新的发展路径的吧。

主持人: 对今天咱们就来聊一聊，马蜂窝在这个 AI 时代，到底都做了哪些比较重要的动作，来让自己保持竞争力。

嘉宾: 嗯，首先他们就是，呃，从内容走向服务嘛，这个很重要的一个举措就是发布了这个 AI 路书。然后另外就是他们把这个 AI 作为核心的驱动力。去做了这个，精调垂直模型，然后另外就是他们跟地方政府有很多的合作啊。通过这种方式来给自己争取一些战略的调整时间。

主持人: OK 了那么今天咱们就是聊了聊这个马蜂窝。在这个 AI 时代，是如何去。通过创新和合作来实现自己的转型和发展的啊无论是这个 AI 路书也好还是这个精调垂直模型也好。感觉都是他们在这个竞争激烈的市场当中找到的新的方向。

嘉宾: OK 了那么以上就是这期播客的全部内容啦，然后非常感谢大家的收听，然后咱们下期再见拜拜！

页面内容均由 AI 生成，仅供参考

created by coze space